# logging_configurator
[![Tests status badge](https://github.com/Dmitrii-I/logging_configurator/workflows/tests/badge.svg?branch=master)](https://github.com/Dmitrii-I/logging_configurator/actions?query=workflow%3Atests)
[![PyPI version](https://badge.fury.io/py/logging-configurator.svg)](https://badge.fury.io/py/logging-configurator)

One-liner logging configurator for Python.

```
from logging_configurator import configure_logging
configure_logging()
```
